import { useState } from "react";
import { COMPANY_NAME, NAVIGATION } from "@/lib/constants";
import { Button } from "@/components/ui/button";
import { Sheet, SheetContent, SheetTrigger } from "@/components/ui/sheet";
import { Menu, PhoneCall, Calendar, ChevronDown } from "lucide-react";
import "./navigation.css";

// Using direct public path to avoid import issues
const logo = "/assets/placeholder.svg";

export default function Header() {
  const [isOpen, setIsOpen] = useState(false);
  const closeSheet = () => setIsOpen(false);

  return (
    <header className="border-b">
      <div className="bg-gradient-to-r from-primary/5 via-primary/10 to-primary/5">
        <div className="container mx-auto px-4 h-12 flex items-center justify-end gap-4">
          <a href="/consultation" className="no-underline">
            <Button
              size="sm"
              variant="default"
              className="text-white hover:text-white hover:bg-primary/90 transition-all duration-300 font-medium flex items-center gap-2 rounded-full px-4"
            >
              <Calendar className="h-4 w-4" />
              Book Free Appointment
            </Button>
          </a>
          <a href="/contact" className="no-underline">
            <Button
              size="sm"
              variant="ghost"
              className="text-primary hover:text-primary/80 hover:bg-primary/10 transition-all duration-300 font-medium flex items-center gap-2 rounded-full px-4"
            >
              <PhoneCall className="h-4 w-4" />
              Get In Touch
            </Button>
          </a>
        </div>
      </div>
      <nav className="container mx-auto px-4 h-16 flex items-center justify-between">
        <a href="/" className="no-underline">
          <img
            src={logo}
            alt={COMPANY_NAME}
            className="h-10 sm:h-12 w-auto"
          />
        </a>

        {/* Desktop Navigation - CSS-only hover dropdowns */}
        <div className="hidden md:flex items-center gap-6">
          {NAVIGATION.map((item) => (
            <div key={item.name} className="nav-item">
              <Button 
                variant="ghost"
                className="font-medium flex items-center gap-1"
              >
                <a href={item.href || (item.children && item.children.length > 0 ? item.children[0].href : "#")} className="no-underline">
                  {item.name}
                </a>
                {item.children && item.children.length > 0 && (
                  <ChevronDown className="h-4 w-4" />
                )}
              </Button>
              
              {item.children && item.children.length > 0 && (
                <div className="dropdown">
                  {item.children.map((child) => (
                    <a 
                      key={child.href} 
                      href={child.href}
                      className="dropdown-link"
                    >
                      {child.name}
                    </a>
                  ))}
                </div>
              )}
            </div>
          ))}
        </div>

        {/* Mobile Navigation */}
        <Sheet open={isOpen} onOpenChange={setIsOpen}>
          <SheetTrigger asChild className="md:hidden">
            <Button
              variant="ghost"
              size="icon"
              id="mobile-nav"
              aria-label="Toggle Navigation Menu"
            >
              <Menu className="h-6 w-6" />
              <span className="sr-only">Navigation</span>
            </Button>
          </SheetTrigger>
          <SheetContent side="right" className="w-[80vw] sm:w-[350px] p-0">
            <div className="flex flex-col h-full">
              <div className="flex-grow overflow-y-auto p-6 space-y-6">
                {NAVIGATION.map((item) => (
                  <div key={item.name} className="space-y-1">
                    <h3 className="text-lg font-semibold mb-2">{item.name}</h3>
                    {item.children ? (
                      item.children.map((child) => (
                        <a
                          key={child.href}
                          href={child.href}
                          onClick={closeSheet}
                          className="block py-2 text-sm text-gray-600 hover:text-primary transition-colors no-underline"
                        >
                          {child.name}
                        </a>
                      ))
                    ) : (
                      <a
                        href={item.href}
                        onClick={closeSheet}
                        className="block py-2 text-sm text-gray-600 hover:text-primary transition-colors no-underline"
                      >
                        {item.name}
                      </a>
                    )}
                  </div>
                ))}

                <div className="space-y-3 pt-4">
                  <a href="/contact" onClick={closeSheet} className="no-underline">
                    <Button
                      className="w-full justify-center gap-2"
                      variant="outline"
                    >
                      <PhoneCall className="h-4 w-4" />
                      Get In Touch
                    </Button>
                  </a>
                  <a href="/consultation" onClick={closeSheet} className="no-underline">
                    <Button
                      variant="default"
                      className="w-full justify-center gap-2"
                    >
                      <Calendar className="h-4 w-4" />
                      Book Free Appointment
                    </Button>
                  </a>
                </div>
              </div>

              {/* Mobile Menu Footer */}
              <div className="border-t p-6">
                <a href="/" className="no-underline">
                  <img
                    src={logo}
                    alt={COMPANY_NAME}
                    className="h-8 w-auto"
                  />
                </a>
              </div>
            </div>
          </SheetContent>
        </Sheet>
      </nav>
    </header>
  );
}